==> QuickAMS-1.0.1-sources.jar: cn/schoolwow/ams/controller/AMSController.java <==
package cn.schoolwow.ams.controller;

import cn.schoolwow.ams.listener.AMSListListener;
import cn.schoolwow.ams.listener.AMSListener;
import cn.schoolwow.ams.listener.AMSOperation;
import cn.schoolwow.ams.util.AMSUtil;
import cn.schoolwow.quickdao.dao.DAO;
import cn.schoolwow.quickdao.dao.dql.condition.Condition;
import cn.schoolwow.quickdao.domain.external.Entity;
import cn.schoolwow.quickdao.domain.external.PageVo;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/ams")
public class AMSController {
    @Value("${spring.profiles.active}")
    private String activeProfile;

    @Resource
    private AMSListener amsListener;

    @Resource
    private AMSListListener amsListListener;

    @Resource
    private List<AMSOperation> amsOperationList;

    private JSONArray blocks = new JSONArray();

    private List<String> scriptPathList = new ArrayList<String>();

    @PostConstruct
    public void postConstruct() throws IOException {
        amsListListener.initialBlocks(blocks);
        scriptPathList.add("router.js");
        scriptPathList.addAll(AMSUtil.getJavascriptResourcePathList("static/operation"));
        scriptPathList.addAll(AMSUtil.getJavascriptResourcePathList("static/page"));
    }

    @RequestMapping("/config")
    public JSONObject config() throws IOException {
        if(!"docker".equals(activeProfile)){
            blocks.clear();
            scriptPathList.clear();

            postConstruct();
        }
        JSONObject config = new JSONObject();
        config.put("applicationName", amsListener.applicationName());
        config.put("blocks", blocks);
        config.put("scriptPathList", scriptPathList);
        return config;
    }

    @RequestMapping("/api/{daoName}/{tableName}/list")
    public JSONObject list(
            @PathVariable("daoName") String daoName,
            @PathVariable("tableName") String tableName,
            @RequestParam Map<String,Object> amsListConditionMap
    ){
        JSONObject amsListCondition = JSON.parseObject(JSON.toJSONString(amsListConditionMap));
        DAO dao = amsListListener.getDAO(daoName);
        Entity entity = dao.getEntity(tableName);
        Condition condition = dao.query(entity.clazz);
        AMSUtil.pageAndSort(condition, amsListCondition);
        AMSUtil.addCompositeQuery(entity, condition, amsListCondition);
        amsListListener.beforeExecuteCondition(daoName, tableName, condition, amsListCondition);
        PageVo pageVo = condition.execute().getPagingList();
        amsListListener.afterExecuteCondition(daoName, tableName, pageVo);
        return AMSUtil.getAMSPagingList(pageVo);
    }

    @RequestMapping("/api/{daoName}/{tableName}/{methodName}")
    public void dispatcherRequest(
            @PathVariable("daoName") String daoName,
            @PathVariable("tableName") String tableName,
            @PathVariable("methodName") String methodName,
            @RequestBody(required = false) JSONObject requestBody
    ) throws Exception {
        for(AMSOperation amsOperation:amsOperationList){
            if(!daoName.equalsIgnoreCase(amsOperation.daoName())){
                continue;
            }
            if(!tableName.equalsIgnoreCase(amsOperation.tableName())){
                continue;
            }
            if(StringUtils.isNoneBlank(amsOperation.methodName())&&!methodName.equalsIgnoreCase(amsOperation.methodName())){
                continue;
            }
            amsOperation.handle(methodName, requestBody);
            return;
        }
        throw new IllegalArgumentException("不支持的操作!dao:"+daoName+",表名:"+tableName+",方法名:"+methodName);
    }
}

==> QuickAMS-1.0.4-sources.jar: cn/schoolwow/ams/controller/AMSController.java <==
package cn.schoolwow.ams.controller;

import cn.schoolwow.ams.listener.AMSListListener;
import cn.schoolwow.ams.listener.AMSListener;
import cn.schoolwow.ams.listener.AMSOperation;
import cn.schoolwow.ams.util.AMSUtil;
import cn.schoolwow.quickdao.dao.DAO;
import cn.schoolwow.quickdao.dao.dql.condition.Condition;
import cn.schoolwow.quickdao.domain.external.Entity;
import cn.schoolwow.quickdao.domain.external.PageVo;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/ams")
public class AMSController {
    @Value("${spring.profiles.active}")
    private String activeProfile;

    @Resource
    private AMSListener amsListener;

    @Resource
    private AMSListListener amsListListener;

    @Resource
    private List<AMSOperation> amsOperationList;

    private JSONArray blocks = new JSONArray();

    private List<String> scriptPathList = new ArrayList<String>();

    @PostConstruct
    public void postConstruct() throws IOException {
        amsListListener.initialBlocks(blocks);
        scriptPathList.add("router.js");
        scriptPathList.addAll(AMSUtil.getJavascriptResourcePathList("static/operation"));
        scriptPathList.addAll(AMSUtil.getJavascriptResourcePathList("static/page"));
    }

    @RequestMapping("/config")
    public JSONObject config() throws IOException {
        if(!"docker".equals(activeProfile)){
            blocks.clear();
            scriptPathList.clear();

            postConstruct();
        }
        JSONObject config = new JSONObject();
        config.put("applicationName", amsListener.applicationName());
        config.put("blocks", blocks);
        config.put("scriptPathList", scriptPathList);
        return config;
    }

    @RequestMapping("/api/{daoName}/{tableName}/list")
    public JSONObject list(
            @PathVariable("daoName") String daoName,
            @PathVariable("tableName") String tableName,
            @RequestParam Map<String,Object> amsListConditionMap
    ){
        JSONObject amsListCondition = JSON.parseObject(JSON.toJSONString(amsListConditionMap));
        DAO dao = amsListListener.getDAO(daoName);
        Entity entity = dao.getEntity(tableName);
        Condition condition = dao.query(entity.clazz);
        AMSUtil.pageAndSort(condition, amsListCondition);
        AMSUtil.addCompositeQuery(entity, condition, amsListCondition);
        amsListListener.beforeExecuteCondition(daoName, tableName, condition, amsListCondition);
        PageVo pageVo = condition.execute().getPagingList();
        amsListListener.afterExecuteCondition(daoName, tableName, pageVo);
        return AMSUtil.getAMSPagingList(pageVo);
    }

    @RequestMapping("/api/{daoName}/{tableName}/create")
    public void create(
            @PathVariable("daoName") String daoName,
            @PathVariable("tableName") String tableName,
            @RequestBody JSONObject createEntity
    ) {
        amsListListener.beforeCreate(daoName, tableName, createEntity);
        DAO dao = amsListListener.getDAO(daoName);
        Entity entity = dao.getEntity(tableName);
        Object instance = createEntity.toJavaObject(entity.clazz);
        dao.insert(instance);
    }

    @RequestMapping("/api/{daoName}/{tableName}/edit")
    public void edit(
            @PathVariable("daoName") String daoName,
            @PathVariable("tableName") String tableName,
            @RequestParam(name = "uniqueFieldNames", required = false, defaultValue = "") String uniqueFieldNames,
            @RequestBody JSONObject updateEntity
    ) {
        amsListListener.beforeEdit(daoName, tableName, updateEntity);
        DAO dao = amsListListener.getDAO(daoName);
        Entity entity = dao.getEntity(tableName);
        if(uniqueFieldNames.isEmpty()){
            Object instance = updateEntity.toJavaObject(entity.clazz);
            dao.update(instance);
        }else{
            dao.partColumn(uniqueFieldNames.split(",", -1)).update(tableName, updateEntity);
        }
    }

    @RequestMapping("/api/{daoName}/{tableName}/delete")
    public void delete(
            @PathVariable("daoName") String daoName,
            @PathVariable("tableName") String tableName,
            @RequestParam Map<String,Object> amsListConditionMap
    ){
        JSONObject amsListCondition = JSON.parseObject(JSON.toJSONString(amsListConditionMap));
        amsListListener.beforeDelete(daoName, tableName, amsListCondition);
        DAO dao = amsListListener.getDAO(daoName);
        Entity entity = dao.getEntity(tableName);
        Condition condition = dao.query(entity.clazz);
        AMSUtil.addCompositeQuery(entity, condition, amsListCondition);
        amsListListener.beforeExecuteCondition(daoName, tableName, condition, amsListCondition);
        condition.execute().delete();
    }

    @RequestMapping("/api/{daoName}/{tableName}/{methodName}")
    public void dispatcherRequest(
            @PathVariable("daoName") String daoName,
            @PathVariable("tableName") String tableName,
            @PathVariable("methodName") String methodName,
            @RequestBody(required = false) JSONObject requestBody
    ) throws Exception {
        for(AMSOperation amsOperation:amsOperationList){
            if(!daoName.equalsIgnoreCase(amsOperation.daoName())){
                continue;
            }
            if(!tableName.equalsIgnoreCase(amsOperation.tableName())){
                continue;
            }
            if(StringUtils.isNoneBlank(amsOperation.methodName())&&!methodName.equalsIgnoreCase(amsOperation.methodName())){
                continue;
            }
            amsOperation.handle(methodName, requestBody);
            return;
        }
        throw new IllegalArgumentException("不支持的操作!dao:"+daoName+",表名:"+tableName+",方法名:"+methodName);
    }
}
